do_the_webp
===========

.. image:: https://img.shields.io/pypi/v/do_the_webp.svg
    :target: https://pypi.python.org/pypi/do_the_webp
    :alt: Latest PyPI version

.. image:: https://travis-ci.org/pedrovanzella/do-the-webp.png
   :target: https://travis-ci.org/pedrovanzella/do-the-webp
   :alt: Latest Travis CI build status

Converts cbz/cbr comic files to webp

Usage
-----

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------
GPLv3

Authors
-------

`do_the_webp` was written by `Pedro Vanzella <pedro@pedrovanzella.com>`_.
